@@ -493,11 +493,11 @@ class AdvancedCustomerServiceUseCase(BaseProcessor):
             # Update persistent global customer ids
             self.global_customer_ids.add(track_id)
             # Initialize customer journey if new
+            is_new_journey = False
             if track_id not in self.customer_journey:
                 self._initialize_customer_journey(track_id, current_time)
-            
+                is_new_journey = True
             journey = self.customer_journey[track_id]
-            
             # Update customer area occupancy
             current_areas = []
             for area_name, polygon in self.customer_areas.items():
@@ -508,7 +508,6 @@ class AdvancedCustomerServiceUseCase(BaseProcessor):
                         'center': customer_center,
                         'timestamp': current_time
                     })
-            
             # Update journey state based on current areas
             journey['current_areas'] = current_areas
             journey['last_seen'] = current_time
@@ -517,7 +516,13 @@ class AdvancedCustomerServiceUseCase(BaseProcessor):
                 'timestamp': current_time,
                 'areas': current_areas.copy()
             })
-            
+            # --- Staff service count: handle BEING_SERVED at initialization ---
+            if is_new_journey and self._is_customer_being_served(track_id, current_time):
+                # Customer starts in BEING_SERVED state, increment staff_service_count for the nearest staff
+                nearest_staff = self._find_nearest_staff(customer_center)
+                if nearest_staff:
+                    staff_id, _ = nearest_staff
+                    self.staff_service_count[staff_id] += 1
             # Update journey state logic
             self._update_customer_journey_state(track_id, current_areas, current_time)
     
@@ -541,16 +546,13 @@ class AdvancedCustomerServiceUseCase(BaseProcessor):
     def _update_customer_journey_state(self, track_id: int, current_areas: List[str], current_time: float):
         """Update customer journey state based on current location."""
         journey = self.customer_journey[track_id]
-        
         # Update areas visited
         journey['areas_visited'].update(current_areas)
-        
         # State transition logic
         if journey['state'] == self.JOURNEY_STATES['ENTERING']:
             if current_areas:
                 journey['state'] = self.JOURNEY_STATES['QUEUING']
                 journey['queue_start_time'] = current_time
-        
         elif journey['state'] == self.JOURNEY_STATES['QUEUING']:
             # Check if customer is being served (near staff)
             if self._is_customer_being_served(track_id, current_time):
@@ -558,7 +560,13 @@ class AdvancedCustomerServiceUseCase(BaseProcessor):
                 journey['service_start_time'] = current_time
                 if journey['queue_start_time']:
                     journey['total_wait_time'] = current_time - journey['queue_start_time']
-        
+                # --- Staff service count: increment only on QUEUING -> BEING_SERVED transition ---
+                customer_center = journey['positions'][-1]['center'] if journey['positions'] else None
+                if customer_center:
+                    nearest_staff = self._find_nearest_staff(customer_center)
+                    if nearest_staff:
+                        staff_id, _ = nearest_staff
+                        self.staff_service_count[staff_id] += 1
         elif journey['state'] == self.JOURNEY_STATES['BEING_SERVED']:
             # Check if service is completed
             if not self._is_customer_being_served(track_id, current_time):
@@ -606,20 +614,17 @@ class AdvancedCustomerServiceUseCase(BaseProcessor):
                 if journey['positions']:
                     customer_center = journey['positions'][-1]['center']
                     nearest_staff = self._find_nearest_staff(customer_center)
-                    
                     if nearest_staff:
                         staff_id, distance = nearest_staff
-                        
-                        # Record interaction
+                        # Record interaction (do not increment staff_service_count here)
                         interaction = {
                             'customer_id': customer_id,
                             'staff_id': staff_id,
                             'distance': distance,
                             'timestamp': current_time
                         }
-                        
                         journey['staff_interactions'].append(interaction)
-                        self.staff_service_count[staff_id] += 1
+        # Note: staff_service_count is now incremented only on state transition or at initialization
     
     def _compile_analytics_results(self, current_time: float) -> Dict[str, Any]:
         """Compile comprehensive analytics results."""
@@ -736,22 +741,39 @@ class AdvancedCustomerServiceUseCase(BaseProcessor):
             "total_active_services": 0,
             "service_efficiency": {}
         }
-        
+
+        # Use service_proximity_threshold from config or fallback to default
+        service_proximity_threshold = getattr(self, '_service_proximity_threshold', 100.0)
+
         for area_name, polygon in self.service_areas.items():
-            # Count customers and staff in service area
-            customers_in_area = len(self.customer_occupancy.get(area_name, []))
-            staff_in_area = len(self.staff_occupancy.get(area_name, []))
-            
+            # Find customers and staff within proximity threshold of the service area polygon
+            customers_in_area = 0
+            staff_in_area = 0
+            # For each customer, check if within threshold of any point in polygon
+            for occ in self.customer_occupancy.get(area_name, []):
+                center = occ.get('center')
+                if center and any(
+                    math.hypot(center[0] - pt[0], center[1] - pt[1]) <= service_proximity_threshold for pt in polygon
+                ):
+                    customers_in_area += 1
+            for occ in self.staff_occupancy.get(area_name, []):
+                center = occ.get('center')
+                if center and any(
+                    math.hypot(center[0] - pt[0], center[1] - pt[1]) <= service_proximity_threshold for pt in polygon
+                ):
+                    staff_in_area += 1
+
             service_analytics["service_areas_status"][area_name] = {
                 "customers": customers_in_area,
                 "staff": staff_in_area,
                 "service_ratio": customers_in_area / max(staff_in_area, 1),
-                "status": "active" if staff_in_area > 0 else "inactive"
+                "status": "active" if staff_in_area > 0 else "inactive",
+                "service_proximity_threshold": service_proximity_threshold
             }
-            
+
             if staff_in_area > 0:
                 service_analytics["total_active_services"] += 1
-        
+
         return service_analytics
     
     def _get_customer_journey_results(self) -> Dict[str, Any]:
@@ -761,7 +783,7 @@ class AdvancedCustomerServiceUseCase(BaseProcessor):
             "journey_states": {state: 0 for state in self.JOURNEY_STATES.values()},
             "average_journey_time": 0.0,
             "popular_areas": {},
-            "journey_patterns": {}
+            # "journey_patterns": {}
         }
         
         journey_times = []
@@ -793,37 +815,49 @@ class AdvancedCustomerServiceUseCase(BaseProcessor):
     def _calculate_analytics(self, current_time: float) -> Dict[str, Any]:
         """Calculate comprehensive business metrics."""
         total_customers = len(self.customer_journey)
-        total_staff = sum(len(staff_list) for staff_list in self.staff_occupancy.values())
-        
+        chunk_ids = getattr(self, '_chunk_customer_ids', set())
+        customers_queuing = 0
+        customers_being_served = 0
+        for track_id in chunk_ids:
+            journey = self.customer_journey.get(track_id)
+            if not journey:
+                continue
+            if journey['state'] == self.JOURNEY_STATES['QUEUING']:
+                customers_queuing += 1
+            elif journey['state'] == self.JOURNEY_STATES['BEING_SERVED']:
+                customers_being_served += 1
+
+        # Use global staff count (unique staff IDs)
+        total_staff = len(self.global_staff_ids)
+
         metrics = {
-            "customer_to_staff_ratio": total_customers / max(total_staff, 1),
+            # Now using per-chunk customer count for ratio
+            "customer_to_staff_ratio": (customers_queuing + customers_being_served) / max(total_staff, 1),
             "service_efficiency": 0.0,
             "queue_performance": 0.0,
             "staff_productivity": 0.0,
             "overall_performance": 0.0
         }
-        
+
         # Calculate service efficiency
         completed_services = sum(1 for j in self.customer_journey.values() 
                                if j['state'] == self.JOURNEY_STATES['COMPLETED'])
         metrics["service_efficiency"] = completed_services / max(total_customers, 1)
-        
+
         # Calculate queue performance
-        customers_queuing = sum(1 for j in self.customer_journey.values() 
-                              if j['state'] == self.JOURNEY_STATES['QUEUING'])
         metrics["queue_performance"] = max(0, 1 - (customers_queuing / max(total_customers, 1)))
-        
+
         # Calculate staff productivity
         total_services = sum(self.staff_service_count.values())
         metrics["staff_productivity"] = total_services / max(total_staff, 1)
-        
+
         # Calculate overall performance
         metrics["overall_performance"] = (
             metrics["service_efficiency"] * 0.4 +
             metrics["queue_performance"] * 0.3 +
             metrics["staff_productivity"] * 0.3
         )
-        
+
         return metrics
     
     def _check_alerts(self, analytics_results: Dict, config: CustomerServiceConfig) -> List[Dict]:
