@@ -548,14 +548,14 @@ class VehicleMonitoringUseCase(BaseProcessor):
         return events
 
 
-    def _generate_tracking_stats(self, counting_summary: Dict, insights: List[str], summary: dict, config: VehicleMonitoringConfig, frame_number: Optional[int] = None, stream_info: Optional[Dict[str, Any]] = None) -> List[Dict]:
+    def _generate_tracking_stats(self, counting_summary: Dict, insights: List[str], summary: str, config: VehicleMonitoringConfig, frame_number: Optional[int] = None, stream_info: Optional[Dict[str, Any]] = None) -> List[Dict]:
         """Generate structured tracking stats for the output format with frame-based keys, including track_ids_info."""
         frame_key = str(frame_number) if frame_number is not None else "current_frame"
         tracking_stats = [{frame_key: []}]
         frame_tracking_stats = tracking_stats[0][frame_key]
         total_vehicles = counting_summary.get("total_count", 0)
-        cumulative = summary.get("total_vehicle_counts", {}) 
-        cumulative_total = sum(cumulative.values()) if cumulative else 0
+        total_vehicle_counts = counting_summary.get("total_vehicle_counts", 0)
+        cumulative_total = sum(total_vehicle_counts.values()) if total_vehicle_counts else 0
         # Add detailed track_ids_info (like people_counting)
         track_ids_info = self._get_track_ids_info(counting_summary.get("detections", []))
                 # Get formatted timestamps
